<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vælg sprog:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemsprog&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Bemærk</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Programmet skal genstartes før ændringen træder i kraft.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Timeseddel</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Firma:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Telefon:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Hjemmeside:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Ikke tilgængelig</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Tilføj valutasymbol i begyndelsen</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Timeløn:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>Skatteprocent:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Valutasymbol:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Kontaktinformation</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportér</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Hjemmeside (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>Outlook CSV (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Eksporteret rapport</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Vis rapporter</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Opret rapport</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Telefon: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Subtotal</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Skatter</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>one: %n time</numerusform>
            <numerusform>other: %n timer</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 timer</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fejl</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Tilføj session</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Dato:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Start:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Slut:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Opgave:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Rediger session</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation type="unfinished">Total</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Stop</translation>
    </message>
    <message>
        <source>Task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished">Timer</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Projekt</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Tilføj</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Session</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Delete</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>I&amp;ndstillinger</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Kolonner</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>&amp;Timer i decimaler</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Direkte redigering</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Sprog...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Vis alt</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Vis kun ubetalte</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Vis kun dette år</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Vis kun denne måned</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Vis kun denne uge</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Frigivet under &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licens</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Kan ikke aflæse tidsdata.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Unavngivet</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Kan ikke opgøre tidsdata.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Timere kører. Stop timere og afslut?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Et program til at holde styr på tidsforbruget</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Opret rapport...</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Vis R&amp;apporter</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Annuller denne session?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Tilføj projekt</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Angiv projektnavn:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Kunne ikke oprette placering.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Kunne ikke flytte placering.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Et projekt med dette navn eksisterer allerede.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Fjern valgte projekt?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Fjern valgte session?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n timer kører</numerusform>
            <numerusform>%n timere kører</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Kapow Punch Clock</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
